==> kubernetes-model-kustomize-6.5.1-sources.jar: io/fabric8/kubernetes/api/model/kustomize/v1beta1/SourceSelectorFluentImpl.java <==
package io.fabric8.kubernetes.api.model.kustomize.v1beta1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import java.lang.Integer;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class SourceSelectorFluentImpl<A extends SourceSelectorFluent<A>> extends BaseFluent<A> implements SourceSelectorFluent<A>{
  public SourceSelectorFluentImpl() {
  }
  public SourceSelectorFluentImpl(SourceSelector instance) {
    this.withFieldPath(instance.getFieldPath()); 
    this.withGroup(instance.getGroup()); 
    this.withKind(instance.getKind()); 
    this.withName(instance.getName()); 
    this.withNamespace(instance.getNamespace()); 
    this.withOptions(instance.getOptions()); 
    this.withVersion(instance.getVersion()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

  }
  private String fieldPath;
  private String group;
  private String kind;
  private String name;
  private String namespace;
  private FieldOptionsBuilder options;
  private String version;
  private Map<String,Object> additionalProperties;
  public String getFieldPath() {
    return this.fieldPath;
  }
  public A withFieldPath(String fieldPath) {
    this.fieldPath=fieldPath; return (A) this;
  }
  public Boolean hasFieldPath() {
    return this.fieldPath != null;
  }
  public String getGroup() {
    return this.group;
  }
  public A withGroup(String group) {
    this.group=group; return (A) this;
  }
  public Boolean hasGroup() {
    return this.group != null;
  }
  public String getKind() {
    return this.kind;
  }
  public A withKind(String kind) {
    this.kind=kind; return (A) this;
  }
  public Boolean hasKind() {
    return this.kind != null;
  }
  public String getName() {
    return this.name;
  }
  public A withName(String name) {
    this.name=name; return (A) this;
  }
  public Boolean hasName() {
    return this.name != null;
  }
  public String getNamespace() {
    return this.namespace;
  }
  public A withNamespace(String namespace) {
    this.namespace=namespace; return (A) this;
  }
  public Boolean hasNamespace() {
    return this.namespace != null;
  }
  
  /**
   * This method has been deprecated, please use method buildOptions instead.
   * @return The buildable object.
   */
  @Deprecated
  public FieldOptions getOptions() {
    return this.options!=null ?this.options.build():null;
  }
  public FieldOptions buildOptions() {
    return this.options!=null ?this.options.build():null;
  }
  public A withOptions(FieldOptions options) {
    _visitables.get("options").remove(this.options);
    if (options!=null){ this.options= new FieldOptionsBuilder(options); _visitables.get("options").add(this.options);} else { this.options = null; _visitables.get("options").remove(this.options); } return (A) this;
  }
  public Boolean hasOptions() {
    return this.options != null;
  }
  public A withNewOptions(Boolean create,String delimiter,String encoding,Integer index) {
    return (A)withOptions(new FieldOptions(create, delimiter, encoding, index));
  }
  public SourceSelectorFluent.OptionsNested<A> withNewOptions() {
    return new SourceSelectorFluentImpl.OptionsNestedImpl();
  }
  public SourceSelectorFluent.OptionsNested<A> withNewOptionsLike(FieldOptions item) {
    return new SourceSelectorFluentImpl.OptionsNestedImpl(item);
  }
  public SourceSelectorFluent.OptionsNested<A> editOptions() {
    return withNewOptionsLike(getOptions());
  }
  public SourceSelectorFluent.OptionsNested<A> editOrNewOptions() {
    return withNewOptionsLike(getOptions() != null ? getOptions(): new FieldOptionsBuilder().build());
  }
  public SourceSelectorFluent.OptionsNested<A> editOrNewOptionsLike(FieldOptions item) {
    return withNewOptionsLike(getOptions() != null ? getOptions(): item);
  }
  public String getVersion() {
    return this.version;
  }
  public A withVersion(String version) {
    this.version=version; return (A) this;
  }
  public Boolean hasVersion() {
    return this.version != null;
  }
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new LinkedHashMap(additionalProperties);} return (A) this;
  }
  public Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    SourceSelectorFluentImpl that = (SourceSelectorFluentImpl) o;
    if (fieldPath != null ? !fieldPath.equals(that.fieldPath) :that.fieldPath != null) return false;
    if (group != null ? !group.equals(that.group) :that.group != null) return false;
    if (kind != null ? !kind.equals(that.kind) :that.kind != null) return false;
    if (name != null ? !name.equals(that.name) :that.name != null) return false;
    if (namespace != null ? !namespace.equals(that.namespace) :that.namespace != null) return false;
    if (options != null ? !options.equals(that.options) :that.options != null) return false;
    if (version != null ? !version.equals(that.version) :that.version != null) return false;
    if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fieldPath,  group,  kind,  name,  namespace,  options,  version,  additionalProperties,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (fieldPath != null) { sb.append("fieldPath:"); sb.append(fieldPath + ","); }
    if (group != null) { sb.append("group:"); sb.append(group + ","); }
    if (kind != null) { sb.append("kind:"); sb.append(kind + ","); }
    if (name != null) { sb.append("name:"); sb.append(name + ","); }
    if (namespace != null) { sb.append("namespace:"); sb.append(namespace + ","); }
    if (options != null) { sb.append("options:"); sb.append(options + ","); }
    if (version != null) { sb.append("version:"); sb.append(version + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  class OptionsNestedImpl<N> extends FieldOptionsFluentImpl<SourceSelectorFluent.OptionsNested<N>> implements SourceSelectorFluent.OptionsNested<N>,Nested<N>{
    OptionsNestedImpl(FieldOptions item) {
      this.builder = new FieldOptionsBuilder(this, item);
    }
    OptionsNestedImpl() {
      this.builder = new FieldOptionsBuilder(this);
    }
    FieldOptionsBuilder builder;
    public N and() {
      return (N) SourceSelectorFluentImpl.this.withOptions(builder.build());
    }
    public N endOptions() {
      return and();
    }
    
  }
  
}

==> kubernetes-model-kustomize-6.7.2-sources.jar: io/fabric8/kubernetes/api/model/kustomize/v1beta1/SourceSelectorFluentImpl.java <==
package io.fabric8.kubernetes.api.model.kustomize.v1beta1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import java.lang.Integer;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class SourceSelectorFluentImpl<A extends SourceSelectorFluent<A>> extends BaseFluent<A> implements SourceSelectorFluent<A>{
  public SourceSelectorFluentImpl() {
  }
  public SourceSelectorFluentImpl(SourceSelector instance) {
    if (instance != null) {
      this.withFieldPath(instance.getFieldPath());
      this.withGroup(instance.getGroup());
      this.withKind(instance.getKind());
      this.withName(instance.getName());
      this.withNamespace(instance.getNamespace());
      this.withOptions(instance.getOptions());
      this.withVersion(instance.getVersion());
      this.withAdditionalProperties(instance.getAdditionalProperties());
    }
  }
  private String fieldPath;
  private String group;
  private String kind;
  private String name;
  private String namespace;
  private FieldOptionsBuilder options;
  private String version;
  private Map<String,Object> additionalProperties;
  public String getFieldPath() {
    return this.fieldPath;
  }
  public A withFieldPath(String fieldPath) {
    this.fieldPath=fieldPath; return (A) this;
  }
  public Boolean hasFieldPath() {
    return this.fieldPath != null;
  }
  public String getGroup() {
    return this.group;
  }
  public A withGroup(String group) {
    this.group=group; return (A) this;
  }
  public Boolean hasGroup() {
    return this.group != null;
  }
  public String getKind() {
    return this.kind;
  }
  public A withKind(String kind) {
    this.kind=kind; return (A) this;
  }
  public Boolean hasKind() {
    return this.kind != null;
  }
  public String getName() {
    return this.name;
  }
  public A withName(String name) {
    this.name=name; return (A) this;
  }
  public Boolean hasName() {
    return this.name != null;
  }
  public String getNamespace() {
    return this.namespace;
  }
  public A withNamespace(String namespace) {
    this.namespace=namespace; return (A) this;
  }
  public Boolean hasNamespace() {
    return this.namespace != null;
  }
  
  /**
   * This method has been deprecated, please use method buildOptions instead.
   * @return The buildable object.
   */
  @Deprecated
  public FieldOptions getOptions() {
    return this.options!=null ?this.options.build():null;
  }
  public FieldOptions buildOptions() {
    return this.options!=null ?this.options.build():null;
  }
  public A withOptions(FieldOptions options) {
    _visitables.get("options").remove(this.options);
    if (options!=null){ this.options= new FieldOptionsBuilder(options); _visitables.get("options").add(this.options);} else { this.options = null; _visitables.get("options").remove(this.options); } return (A) this;
  }
  public Boolean hasOptions() {
    return this.options != null;
  }
  public A withNewOptions(Boolean create,String delimiter,String encoding,Integer index) {
    return (A)withOptions(new FieldOptions(create, delimiter, encoding, index));
  }
  public SourceSelectorFluentImpl.OptionsNested<A> withNewOptions() {
    return new SourceSelectorFluentImpl.OptionsNestedImpl();
  }
  public SourceSelectorFluentImpl.OptionsNested<A> withNewOptionsLike(FieldOptions item) {
    return new SourceSelectorFluentImpl.OptionsNestedImpl(item);
  }
  public SourceSelectorFluentImpl.OptionsNested<A> editOptions() {
    return withNewOptionsLike(getOptions());
  }
  public SourceSelectorFluentImpl.OptionsNested<A> editOrNewOptions() {
    return withNewOptionsLike(getOptions() != null ? getOptions(): new FieldOptionsBuilder().build());
  }
  public SourceSelectorFluentImpl.OptionsNested<A> editOrNewOptionsLike(FieldOptions item) {
    return withNewOptionsLike(getOptions() != null ? getOptions(): item);
  }
  public String getVersion() {
    return this.version;
  }
  public A withVersion(String version) {
    this.version=version; return (A) this;
  }
  public Boolean hasVersion() {
    return this.version != null;
  }
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new LinkedHashMap(additionalProperties);} return (A) this;
  }
  public Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    SourceSelectorFluentImpl that = (SourceSelectorFluentImpl) o;
    if (!java.util.Objects.equals(fieldPath, that.fieldPath)) return false;

    if (!java.util.Objects.equals(group, that.group)) return false;

    if (!java.util.Objects.equals(kind, that.kind)) return false;

    if (!java.util.Objects.equals(name, that.name)) return false;

    if (!java.util.Objects.equals(namespace, that.namespace)) return false;

    if (!java.util.Objects.equals(options, that.options)) return false;

    if (!java.util.Objects.equals(version, that.version)) return false;

    if (!java.util.Objects.equals(additionalProperties, that.additionalProperties)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fieldPath,  group,  kind,  name,  namespace,  options,  version,  additionalProperties,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (fieldPath != null) { sb.append("fieldPath:"); sb.append(fieldPath + ","); }
    if (group != null) { sb.append("group:"); sb.append(group + ","); }
    if (kind != null) { sb.append("kind:"); sb.append(kind + ","); }
    if (name != null) { sb.append("name:"); sb.append(name + ","); }
    if (namespace != null) { sb.append("namespace:"); sb.append(namespace + ","); }
    if (options != null) { sb.append("options:"); sb.append(options + ","); }
    if (version != null) { sb.append("version:"); sb.append(version + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  class OptionsNestedImpl<N> extends FieldOptionsFluentImpl<SourceSelectorFluentImpl.OptionsNested<N>> implements SourceSelectorFluentImpl.OptionsNested<N>,Nested<N>{
    OptionsNestedImpl(FieldOptions item) {
      this.builder = new FieldOptionsBuilder(this, item);
    }
    OptionsNestedImpl() {
      this.builder = new FieldOptionsBuilder(this);
    }
    FieldOptionsBuilder builder;
    public N and() {
      return (N) SourceSelectorFluentImpl.this.withOptions(builder.build());
    }
    public N endOptions() {
      return and();
    }
    
  }
  
}
